From a7260d569449cda6453d36db515834b35e77d550 Mon Sep 17 00:00:00 2001
From: Walter Van Herck <w.van.herck@fz-juelich.de>
Date: Tue, 4 Jul 2017 11:33:27 +0200
Subject: [PATCH] Propagate version number and regenerate Python bindings and
 doxygen

---
 Doc/Doxygen/Doxyfile                |   2 +-
 auto/Wrap/doxygen_core.i            | 267 ++++++++++++++++++++--------
 auto/Wrap/libBornAgainCore.py       |  40 ++++-
 auto/Wrap/libBornAgainCore_wrap.cpp |  42 ++++-
 auto/Wrap/libBornAgainFit_wrap.cpp  |   2 +-
 5 files changed, 261 insertions(+), 92 deletions(-)

diff --git a/Doc/Doxygen/Doxyfile b/Doc/Doxygen/Doxyfile
index 450bd2b301d..15516631ff9 100644
--- a/Doc/Doxygen/Doxyfile
+++ b/Doc/Doxygen/Doxyfile
@@ -38,7 +38,7 @@ PROJECT_NAME           = "BornAgain"
 # could be handy for archiving the generated documentation or if some version
 # control system is used.
 
-PROJECT_NUMBER         = 1.8.99
+PROJECT_NUMBER         = 1.9.0
 
 # Using the PROJECT_BRIEF tag one can provide an optional one line description
 # for a project that appears at the top of each page and should give viewer a
diff --git a/auto/Wrap/doxygen_core.i b/auto/Wrap/doxygen_core.i
index 419d2179f61..b1589288e33 100644
--- a/auto/Wrap/doxygen_core.i
+++ b/auto/Wrap/doxygen_core.i
@@ -603,6 +603,21 @@ C++ includes: ComputationStatus.h
 ";
 
 
+// File: classConesWithLimitsDistributionBuilder.xml
+%feature("docstring") ConesWithLimitsDistributionBuilder "
+
+Cones with the distribution applied to the angle and RealLimits defined.
+
+C++ includes: ParticleDistributionsBuilder.h
+";
+
+%feature("docstring")  ConesWithLimitsDistributionBuilder::ConesWithLimitsDistributionBuilder "ConesWithLimitsDistributionBuilder::ConesWithLimitsDistributionBuilder()
+";
+
+%feature("docstring")  ConesWithLimitsDistributionBuilder::buildSample "MultiLayer * ConesWithLimitsDistributionBuilder::buildSample() const 
+";
+
+
 // File: classConstKBinAxis.xml
 %feature("docstring") ConstKBinAxis "
 
@@ -1356,6 +1371,11 @@ Returns true if the distribution is in the limit case of a Dirac delta distribut
 Calls the  INodeVisitor's visit method. 
 ";
 
+%feature("docstring")  DistributionLogNormal::setUnits "void DistributionLogNormal::setUnits(const std::string &units)
+
+Sets distribution units. 
+";
+
 
 // File: classDistributionLorentz.xml
 %feature("docstring") DistributionLorentz "
@@ -5588,12 +5608,12 @@ C++ includes: HomogeneousMaterial.h
 Constructs a default material (vacuum). 
 ";
 
-%feature("docstring")  HomogeneousMaterial::HomogeneousMaterial "HomogeneousMaterial::HomogeneousMaterial(const std::string &name, const complex_t refractive_index, kvector_t magnetic_field=kvector_t())
+%feature("docstring")  HomogeneousMaterial::HomogeneousMaterial "HomogeneousMaterial::HomogeneousMaterial(const std::string &name, const complex_t refractive_index, kvector_t magnetization=kvector_t())
 
 Constructs a material with  name and  refractive_index. 
 ";
 
-%feature("docstring")  HomogeneousMaterial::HomogeneousMaterial "HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetic_field=kvector_t())
+%feature("docstring")  HomogeneousMaterial::HomogeneousMaterial "HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetization=kvector_t())
 
 Constructs a material with  name and refractive_index parameters delta and beta (n = 1 - delta + i*beta). 
 ";
@@ -5603,7 +5623,7 @@ Constructs a material with  name and refractive_index parameters delta and beta
 
 %feature("docstring")  HomogeneousMaterial::inverted "HomogeneousMaterial HomogeneousMaterial::inverted() const
 
-Constructs a material with inverted magnetic field. 
+Constructs a material with inverted magnetization. 
 ";
 
 %feature("docstring")  HomogeneousMaterial::refractiveIndex "complex_t HomogeneousMaterial::refractiveIndex() const 
@@ -5623,25 +5643,22 @@ Indicates whether the interaction with the material is scalar. This means that d
 %feature("docstring")  HomogeneousMaterial::isMagneticMaterial "bool HomogeneousMaterial::isMagneticMaterial() const 
 ";
 
-%feature("docstring")  HomogeneousMaterial::magneticField "kvector_t HomogeneousMaterial::magneticField() const
+%feature("docstring")  HomogeneousMaterial::magnetization "kvector_t HomogeneousMaterial::magnetization() const
 
-Get the magnetic field (in Tesla) 
+Get the magnetization (in A/m) 
 ";
 
-%feature("docstring")  HomogeneousMaterial::setMagneticField "void HomogeneousMaterial::setMagneticField(const kvector_t magnetic_field)
+%feature("docstring")  HomogeneousMaterial::setMagnetization "void HomogeneousMaterial::setMagnetization(const kvector_t magnetization)
 
-Set the magnetic field (in Tesla) 
+Set the magnetizationd (in A/m) 
 ";
 
 %feature("docstring")  HomogeneousMaterial::scalarSLD "complex_t HomogeneousMaterial::scalarSLD(const WavevectorInfo &wavevectors) const 
 ";
 
-%feature("docstring")  HomogeneousMaterial::polarizedSLD "Eigen::Matrix2cd HomogeneousMaterial::polarizedSLD(const WavevectorInfo &wavevectors) const 
-";
-
-%feature("docstring")  HomogeneousMaterial::polarizedSLDExperimental "Eigen::Matrix2cd HomogeneousMaterial::polarizedSLDExperimental(const WavevectorInfo &wavevectors) const
+%feature("docstring")  HomogeneousMaterial::polarizedSLD "Eigen::Matrix2cd HomogeneousMaterial::polarizedSLD(const WavevectorInfo &wavevectors) const
 
-Get the scattering matrix for a material defined by its magnetization (experimental) 
+Get the scattering matrix for a material defined by its magnetization. 
 ";
 
 %feature("docstring")  HomogeneousMaterial::transformedMaterial "HomogeneousMaterial HomogeneousMaterial::transformedMaterial(const Transform3D &transform) const 
@@ -6224,6 +6241,11 @@ Returns equidistant interpolation points from xmin to xmax.
 Returns true if the distribution is in the limit case of a Dirac delta distribution. 
 ";
 
+%feature("docstring")  IDistribution1D::setUnits "void IDistribution1D::setUnits(const std::string &units)
+
+Sets distribution units. 
+";
+
 
 // File: classIFactory.xml
 %feature("docstring") IFactory "
@@ -9040,45 +9062,6 @@ C++ includes: NodeIterator.h
 // File: classLabelMap.xml
 %feature("docstring") LabelMap "";
 
-%feature("docstring")  LabelMap::LabelMap "LabelMap< Key >::LabelMap()
-";
-
-%feature("docstring")  LabelMap::~LabelMap "virtual LabelMap< Key >::~LabelMap()
-";
-
-%feature("docstring")  LabelMap::clear "void LabelMap< Key >::clear()
-";
-
-%feature("docstring")  LabelMap::begin "const_iterator LabelMap< Key >::begin() const 
-";
-
-%feature("docstring")  LabelMap::end "const_iterator LabelMap< Key >::end() const 
-";
-
-%feature("docstring")  LabelMap::begin "iterator LabelMap< Key >::begin()
-";
-
-%feature("docstring")  LabelMap::end "iterator LabelMap< Key >::end()
-";
-
-%feature("docstring")  LabelMap::size "size_t LabelMap< Key >::size()
-";
-
-%feature("docstring")  LabelMap::insert "void LabelMap< Key >::insert(const Key &key, const std::string &object)
-";
-
-%feature("docstring")  LabelMap::find "const iterator LabelMap< Key >::find(const Key &key) const 
-";
-
-%feature("docstring")  LabelMap::find "iterator LabelMap< Key >::find(const Key &key)
-";
-
-%feature("docstring")  LabelMap::erase "void LabelMap< Key >::erase(const Key &key)
-";
-
-%feature("docstring")  LabelMap::value "const std::string& LabelMap< Key >::value(const Key &key)
-";
-
 
 // File: classLargeCylindersInDWBABuilder.xml
 %feature("docstring") LargeCylindersInDWBABuilder "
@@ -10125,6 +10108,54 @@ C++ includes: ZLimits.h
 ";
 
 
+// File: classOrderedMap.xml
+%feature("docstring") OrderedMap "
+
+Ordered map which saves the order of insertion.
+
+C++ includes: OrderedMap.h
+";
+
+%feature("docstring")  OrderedMap::OrderedMap "OrderedMap< Key, Object >::OrderedMap()
+";
+
+%feature("docstring")  OrderedMap::~OrderedMap "virtual OrderedMap< Key, Object >::~OrderedMap()
+";
+
+%feature("docstring")  OrderedMap::clear "void OrderedMap< Key, Object >::clear()
+";
+
+%feature("docstring")  OrderedMap::begin "const_iterator OrderedMap< Key, Object >::begin() const 
+";
+
+%feature("docstring")  OrderedMap::end "const_iterator OrderedMap< Key, Object >::end() const 
+";
+
+%feature("docstring")  OrderedMap::begin "iterator OrderedMap< Key, Object >::begin()
+";
+
+%feature("docstring")  OrderedMap::end "iterator OrderedMap< Key, Object >::end()
+";
+
+%feature("docstring")  OrderedMap::size "size_t OrderedMap< Key, Object >::size()
+";
+
+%feature("docstring")  OrderedMap::insert "void OrderedMap< Key, Object >::insert(const Key &key, const Object &object)
+";
+
+%feature("docstring")  OrderedMap::find "iterator OrderedMap< Key, Object >::find(const Key &key)
+";
+
+%feature("docstring")  OrderedMap::find "const_iterator OrderedMap< Key, Object >::find(const Key &key) const 
+";
+
+%feature("docstring")  OrderedMap::erase "size_t OrderedMap< Key, Object >::erase(const Key &key)
+";
+
+%feature("docstring")  OrderedMap::value "const Object& OrderedMap< Key, Object >::value(const Key &key)
+";
+
+
 // File: classExceptions_1_1OutOfBoundsException.xml
 %feature("docstring") Exceptions::OutOfBoundsException "";
 
@@ -11867,6 +11898,21 @@ C++ includes: RotatedPyramidsBuilder.h
 ";
 
 
+// File: classRotatedPyramidsDistributionBuilder.xml
+%feature("docstring") RotatedPyramidsDistributionBuilder "
+
+Rotated Pyramids with the distribution applied to the rotation angle.
+
+C++ includes: ParticleDistributionsBuilder.h
+";
+
+%feature("docstring")  RotatedPyramidsDistributionBuilder::RotatedPyramidsDistributionBuilder "RotatedPyramidsDistributionBuilder::RotatedPyramidsDistributionBuilder()
+";
+
+%feature("docstring")  RotatedPyramidsDistributionBuilder::buildSample "MultiLayer * RotatedPyramidsDistributionBuilder::buildSample() const 
+";
+
+
 // File: classRotatedSquareLatticeBuilder.xml
 %feature("docstring") RotatedSquareLatticeBuilder "
 
@@ -12116,76 +12162,76 @@ C++ includes: SampleLabelHandler.h
 %feature("docstring")  SampleLabelHandler::SampleLabelHandler "SampleLabelHandler::SampleLabelHandler()
 ";
 
-%feature("docstring")  SampleLabelHandler::getFormFactorMap "formfactors_t* SampleLabelHandler::getFormFactorMap()
+%feature("docstring")  SampleLabelHandler::formFactorMap "formfactors_t* SampleLabelHandler::formFactorMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getInterferenceFunctionMap "interferences_t* SampleLabelHandler::getInterferenceFunctionMap()
+%feature("docstring")  SampleLabelHandler::interferenceFunctionMap "interferences_t* SampleLabelHandler::interferenceFunctionMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getLayerMap "layers_t* SampleLabelHandler::getLayerMap()
+%feature("docstring")  SampleLabelHandler::layerMap "layers_t* SampleLabelHandler::layerMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getParticleLayoutMap "layouts_t* SampleLabelHandler::getParticleLayoutMap()
+%feature("docstring")  SampleLabelHandler::particleLayoutMap "layouts_t* SampleLabelHandler::particleLayoutMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getMaterialMap "materials_t* SampleLabelHandler::getMaterialMap()
+%feature("docstring")  SampleLabelHandler::materialMap "materials_t* SampleLabelHandler::materialMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getMultiLayerMap "multilayers_t* SampleLabelHandler::getMultiLayerMap()
+%feature("docstring")  SampleLabelHandler::multiLayerMap "multilayers_t* SampleLabelHandler::multiLayerMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getParticleCompositionMap "particlecompositions_t* SampleLabelHandler::getParticleCompositionMap()
+%feature("docstring")  SampleLabelHandler::particleCompositionMap "particlecompositions_t* SampleLabelHandler::particleCompositionMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getParticleDistributionsMap "particledistributions_t* SampleLabelHandler::getParticleDistributionsMap()
+%feature("docstring")  SampleLabelHandler::particleDistributionsMap "particledistributions_t* SampleLabelHandler::particleDistributionsMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getParticleMap "particles_t* SampleLabelHandler::getParticleMap()
+%feature("docstring")  SampleLabelHandler::particleMap "particles_t* SampleLabelHandler::particleMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getParticleCoreShellMap "particlescoreshell_t* SampleLabelHandler::getParticleCoreShellMap()
+%feature("docstring")  SampleLabelHandler::particleCoreShellMap "particlescoreshell_t* SampleLabelHandler::particleCoreShellMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getRotationsMap "rotations_t* SampleLabelHandler::getRotationsMap()
+%feature("docstring")  SampleLabelHandler::rotationsMap "rotations_t* SampleLabelHandler::rotationsMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getLayerRoughnessMap "roughnesses_t* SampleLabelHandler::getLayerRoughnessMap()
+%feature("docstring")  SampleLabelHandler::layerRoughnessMap "roughnesses_t* SampleLabelHandler::layerRoughnessMap()
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelParticle "std::string SampleLabelHandler::getLabelParticle(const IAbstractParticle *sample)
+%feature("docstring")  SampleLabelHandler::labelParticle "std::string SampleLabelHandler::labelParticle(const IAbstractParticle *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelFormFactor "std::string SampleLabelHandler::getLabelFormFactor(const IFormFactor *sample)
+%feature("docstring")  SampleLabelHandler::labelFormFactor "std::string SampleLabelHandler::labelFormFactor(const IFormFactor *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelInterferenceFunction "std::string SampleLabelHandler::getLabelInterferenceFunction(const IInterferenceFunction *sample)
+%feature("docstring")  SampleLabelHandler::labelInterferenceFunction "std::string SampleLabelHandler::labelInterferenceFunction(const IInterferenceFunction *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelLayout "std::string SampleLabelHandler::getLabelLayout(const ILayout *sample)
+%feature("docstring")  SampleLabelHandler::labelLayout "std::string SampleLabelHandler::labelLayout(const ILayout *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelMaterial "std::string SampleLabelHandler::getLabelMaterial(const HomogeneousMaterial *sample)
+%feature("docstring")  SampleLabelHandler::labelMaterial "std::string SampleLabelHandler::labelMaterial(const HomogeneousMaterial *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelRotation "std::string SampleLabelHandler::getLabelRotation(const IRotation *sample)
+%feature("docstring")  SampleLabelHandler::labelRotation "std::string SampleLabelHandler::labelRotation(const IRotation *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelLayer "std::string SampleLabelHandler::getLabelLayer(const Layer *sample)
+%feature("docstring")  SampleLabelHandler::labelLayer "std::string SampleLabelHandler::labelLayer(const Layer *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelRoughness "std::string SampleLabelHandler::getLabelRoughness(const LayerRoughness *sample)
+%feature("docstring")  SampleLabelHandler::labelRoughness "std::string SampleLabelHandler::labelRoughness(const LayerRoughness *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelMultiLayer "std::string SampleLabelHandler::getLabelMultiLayer(const MultiLayer *sample)
+%feature("docstring")  SampleLabelHandler::labelMultiLayer "std::string SampleLabelHandler::labelMultiLayer(const MultiLayer *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelParticleComposition "std::string SampleLabelHandler::getLabelParticleComposition(const ParticleComposition *sample)
+%feature("docstring")  SampleLabelHandler::labelParticleComposition "std::string SampleLabelHandler::labelParticleComposition(const ParticleComposition *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelParticleCoreShell "std::string SampleLabelHandler::getLabelParticleCoreShell(const ParticleCoreShell *sample)
+%feature("docstring")  SampleLabelHandler::labelParticleCoreShell "std::string SampleLabelHandler::labelParticleCoreShell(const ParticleCoreShell *sample)
 ";
 
-%feature("docstring")  SampleLabelHandler::getLabelParticleDistribution "std::string SampleLabelHandler::getLabelParticleDistribution(const ParticleDistribution *sample)
+%feature("docstring")  SampleLabelHandler::labelParticleDistribution "std::string SampleLabelHandler::labelParticleDistribution(const ParticleDistribution *sample)
 ";
 
 %feature("docstring")  SampleLabelHandler::insertMaterial "void SampleLabelHandler::insertMaterial(const HomogeneousMaterial *sample)
@@ -12969,6 +13015,21 @@ Put into a clean state for running a simulation.
 ";
 
 
+// File: classSpheresWithLimitsDistributionBuilder.xml
+%feature("docstring") SpheresWithLimitsDistributionBuilder "
+
+Spherical particles with the distribution applied to the radius and RealLimits defined.
+
+C++ includes: ParticleDistributionsBuilder.h
+";
+
+%feature("docstring")  SpheresWithLimitsDistributionBuilder::SpheresWithLimitsDistributionBuilder "SpheresWithLimitsDistributionBuilder::SpheresWithLimitsDistributionBuilder()
+";
+
+%feature("docstring")  SpheresWithLimitsDistributionBuilder::buildSample "MultiLayer * SpheresWithLimitsDistributionBuilder::buildSample() const 
+";
+
+
 // File: classSphericalDetector.xml
 %feature("docstring") SphericalDetector "
 
@@ -13707,10 +13768,13 @@ C++ includes: ZLimits.h
 // File: namespace_0D329.xml
 
 
-// File: namespace_0D368.xml
+// File: namespace_0D338.xml
+
 
+// File: namespace_0D370.xml
 
-// File: namespace_0D478.xml
+
+// File: namespace_0D480.xml
 
 
 // File: namespace_0D54.xml
@@ -14076,6 +14140,23 @@ Returns the safe relative difference, which is |(a-b)/b| except in special cases
 ";
 
 
+// File: namespaceParameterUtils.xml
+%feature("docstring")  ParameterUtils::isAngleRelated "bool ParameterUtils::isAngleRelated(const std::string &par_name)
+
+Returns true if given parameter name is related to angles. 
+";
+
+%feature("docstring")  ParameterUtils::mainParUnits "std::string ParameterUtils::mainParUnits(const ParticleDistribution &distr)
+
+Returns units of main parameter. 
+";
+
+%feature("docstring")  ParameterUtils::poolParameterUnits "std::string ParameterUtils::poolParameterUnits(const IParameterized &node, const std::string &parName)
+
+Returns units of main parameter. 
+";
+
+
 // File: namespacePythonFormatting.xml
 %feature("docstring")  PythonFormatting::representShape2D "BA_CORE_API_ std::string PythonFormatting::representShape2D(const std::string &indent, const IShape2D *ishape, bool mask_value, std::function< std::string(double)> printValueFunc)
 
@@ -14097,6 +14178,9 @@ Returns fixed Python code snippet that defines the function \"runSimulation\".
 %feature("docstring")  PythonFormatting::printDegrees "BA_CORE_API_ std::string PythonFormatting::printDegrees(double input)
 ";
 
+%feature("docstring")  PythonFormatting::printValue "BA_CORE_API_ std::string PythonFormatting::printValue(double value, const std::string &units)
+";
+
 %feature("docstring")  PythonFormatting::isSquare "BA_CORE_API_ bool PythonFormatting::isSquare(double length1, double length2, double angle)
 ";
 
@@ -14121,6 +14205,26 @@ Returns parameter value, followed by its unit multiplicator (like \"* nm\").
 Returns comma-separated list of parameter values, including unit multiplicator (like \"* nm\"). 
 ";
 
+%feature("docstring")  PythonFormatting::printDistribution "BA_CORE_API_ std::string PythonFormatting::printDistribution(const IDistribution1D &par_distr, const std::string &units)
+
+Prints distribution with constructor parameters in given units. ba.DistributionGaussian(2.0*deg, 0.02*deg) 
+";
+
+%feature("docstring")  PythonFormatting::printRealLimits "BA_CORE_API_ std::string PythonFormatting::printRealLimits(const RealLimits &limits, const std::string &units)
+";
+
+%feature("docstring")  PythonFormatting::printRealLimitsArg "BA_CORE_API_ std::string PythonFormatting::printRealLimitsArg(const RealLimits &limits, const std::string &units)
+
+Prints RealLimits in the form of argument (in the context of  ParameterDistribution and similar). Default RealLimits will not be printed, any other will be printed as \", ba.RealLimits.limited(1*deg, 2*deg)\" 
+";
+
+%feature("docstring")  PythonFormatting::printParameterDistribution "BA_CORE_API_ std::string PythonFormatting::printParameterDistribution(const ParameterDistribution &par_distr, const std::string &distVarName, const std::string &units)
+
+Prints  ParameterDistribution. distVarName is a string representing  IDistribution1D variable, e.g. \"distr_1\"
+
+ba.ParameterDistribution(\"/Particle/Height\", distr_1, 10, 0.0, ba.RealLimits.limited(1*nm,2*nm)) 
+";
+
 %feature("docstring")  PythonFormatting::simulationToPython "std::string PythonFormatting::simulationToPython(GISASSimulation *simulation)
 ";
 
@@ -15353,6 +15457,12 @@ Recursive bisection to determine the number of the deepest layer where RT comput
 // File: ParameterSample_8h.xml
 
 
+// File: ParameterUtils_8cpp.xml
+
+
+// File: ParameterUtils_8h.xml
+
+
 // File: RealParameter_8cpp.xml
 
 
@@ -15945,6 +16055,9 @@ Template function to create an integrator object.
 // File: Numeric_8h.xml
 
 
+// File: OrderedMap_8h.xml
+
+
 // File: Precomputed_8cpp.xml
 
 
diff --git a/auto/Wrap/libBornAgainCore_wrap.cpp b/auto/Wrap/libBornAgainCore_wrap.cpp
index ae772c36f8e..e34ec0002ab 100644
--- a/auto/Wrap/libBornAgainCore_wrap.cpp
+++ b/auto/Wrap/libBornAgainCore_wrap.cpp
@@ -5989,7 +5989,7 @@ SWIG_AsVal_std_complex_Sl_double_Sg_  (PyObject *o, std::complex<double>* val)
 
 
 SWIGINTERNINLINE PyObject*
-SWIG_From_std_complex_Sl_double_Sg_  (/*@SWIG:/home/pospelov/software/local/share/swig/3.0.8/typemaps/swigmacros.swg,104,%ifcplusplus@*/
+SWIG_From_std_complex_Sl_double_Sg_  (/*@SWIG:/usr/share/swig3.0/typemaps/swigmacros.swg,104,%ifcplusplus@*/
 
 const std::complex<double>&
 
@@ -112551,7 +112551,14 @@ static PyMethodDef SwigMethods[] = {
 		"Returns true if the distribution is in the limit case of a Dirac delta distribution. \n"
 		"\n"
 		""},
-	 { (char *)"IDistribution1D_setUnits", _wrap_IDistribution1D_setUnits, METH_VARARGS, (char *)"IDistribution1D_setUnits(IDistribution1D self, std::string const & units)"},
+	 { (char *)"IDistribution1D_setUnits", _wrap_IDistribution1D_setUnits, METH_VARARGS, (char *)"\n"
+		"IDistribution1D_setUnits(IDistribution1D self, std::string const & units)\n"
+		"\n"
+		"void IDistribution1D::setUnits(const std::string &units)\n"
+		"\n"
+		"Sets distribution units. \n"
+		"\n"
+		""},
 	 { (char *)"IDistribution1D_swigregister", IDistribution1D_swigregister, METH_VARARGS, NULL},
 	 { (char *)"new_DistributionGate", _wrap_new_DistributionGate, METH_VARARGS, (char *)"\n"
 		"DistributionGate()\n"
@@ -112832,7 +112839,14 @@ static PyMethodDef SwigMethods[] = {
 		"Calls the  INodeVisitor's visit method. \n"
 		"\n"
 		""},
-	 { (char *)"DistributionLogNormal_setUnits", _wrap_DistributionLogNormal_setUnits, METH_VARARGS, (char *)"DistributionLogNormal_setUnits(DistributionLogNormal self, std::string const & units)"},
+	 { (char *)"DistributionLogNormal_setUnits", _wrap_DistributionLogNormal_setUnits, METH_VARARGS, (char *)"\n"
+		"DistributionLogNormal_setUnits(DistributionLogNormal self, std::string const & units)\n"
+		"\n"
+		"void DistributionLogNormal::setUnits(const std::string &units)\n"
+		"\n"
+		"Sets distribution units. \n"
+		"\n"
+		""},
 	 { (char *)"DistributionLogNormal_swigregister", DistributionLogNormal_swigregister, METH_VARARGS, NULL},
 	 { (char *)"new_DistributionCosine", _wrap_new_DistributionCosine, METH_VARARGS, (char *)"\n"
 		"DistributionCosine()\n"
@@ -117593,7 +117607,7 @@ static PyMethodDef SwigMethods[] = {
 		"HomogeneousMaterial(std::string const & name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetization)\n"
 		"new_HomogeneousMaterial(std::string const & name, double refractive_index_delta, double refractive_index_beta) -> HomogeneousMaterial\n"
 		"\n"
-		"HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetic_field=kvector_t())\n"
+		"HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetization=kvector_t())\n"
 		"\n"
 		"Constructs a material with  name and refractive_index parameters delta and beta (n = 1 - delta + i*beta). \n"
 		"\n"
@@ -117609,7 +117623,7 @@ static PyMethodDef SwigMethods[] = {
 		"\n"
 		"HomogeneousMaterial HomogeneousMaterial::inverted() const\n"
 		"\n"
-		"Constructs a material with inverted magnetic field. \n"
+		"Constructs a material with inverted magnetization. \n"
 		"\n"
 		""},
 	 { (char *)"HomogeneousMaterial_refractiveIndex", _wrap_HomogeneousMaterial_refractiveIndex, METH_VARARGS, (char *)"\n"
@@ -117644,8 +117658,22 @@ static PyMethodDef SwigMethods[] = {
 		"bool HomogeneousMaterial::isMagneticMaterial() const \n"
 		"\n"
 		""},
-	 { (char *)"HomogeneousMaterial_magnetization", _wrap_HomogeneousMaterial_magnetization, METH_VARARGS, (char *)"HomogeneousMaterial_magnetization(HomogeneousMaterial self) -> kvector_t"},
-	 { (char *)"HomogeneousMaterial_setMagnetization", _wrap_HomogeneousMaterial_setMagnetization, METH_VARARGS, (char *)"HomogeneousMaterial_setMagnetization(HomogeneousMaterial self, kvector_t magnetization)"},
+	 { (char *)"HomogeneousMaterial_magnetization", _wrap_HomogeneousMaterial_magnetization, METH_VARARGS, (char *)"\n"
+		"HomogeneousMaterial_magnetization(HomogeneousMaterial self) -> kvector_t\n"
+		"\n"
+		"kvector_t HomogeneousMaterial::magnetization() const\n"
+		"\n"
+		"Get the magnetization (in A/m) \n"
+		"\n"
+		""},
+	 { (char *)"HomogeneousMaterial_setMagnetization", _wrap_HomogeneousMaterial_setMagnetization, METH_VARARGS, (char *)"\n"
+		"HomogeneousMaterial_setMagnetization(HomogeneousMaterial self, kvector_t magnetization)\n"
+		"\n"
+		"void HomogeneousMaterial::setMagnetization(const kvector_t magnetization)\n"
+		"\n"
+		"Set the magnetizationd (in A/m) \n"
+		"\n"
+		""},
 	 { (char *)"HomogeneousMaterial_scalarSLD", _wrap_HomogeneousMaterial_scalarSLD, METH_VARARGS, (char *)"\n"
 		"HomogeneousMaterial_scalarSLD(HomogeneousMaterial self, WavevectorInfo wavevectors) -> complex_t\n"
 		"\n"
diff --git a/auto/Wrap/libBornAgainFit_wrap.cpp b/auto/Wrap/libBornAgainFit_wrap.cpp
index 980a19744c5..182abc5541c 100644
--- a/auto/Wrap/libBornAgainFit_wrap.cpp
+++ b/auto/Wrap/libBornAgainFit_wrap.cpp
@@ -5627,7 +5627,7 @@ SWIG_AsVal_std_complex_Sl_double_Sg_  (PyObject *o, std::complex<double>* val)
 
 
 SWIGINTERNINLINE PyObject*
-SWIG_From_std_complex_Sl_double_Sg_  (/*@SWIG:/home/pospelov/software/local/share/swig/3.0.8/typemaps/swigmacros.swg,104,%ifcplusplus@*/
+SWIG_From_std_complex_Sl_double_Sg_  (/*@SWIG:/usr/share/swig3.0/typemaps/swigmacros.swg,104,%ifcplusplus@*/
 
 const std::complex<double>&
 
diff --git a/auto/Wrap/libBornAgainCore.py b/auto/Wrap/libBornAgainCore.py
index 333f41dc936..ee9b5814f6a 100644
--- a/auto/Wrap/libBornAgainCore.py
+++ b/auto/Wrap/libBornAgainCore.py
@@ -7888,7 +7888,14 @@ class IDistribution1D(ICloneable, INode):
 
 
     def setUnits(self, units):
-        """setUnits(IDistribution1D self, std::string const & units)"""
+        """
+        setUnits(IDistribution1D self, std::string const & units)
+
+        void IDistribution1D::setUnits(const std::string &units)
+
+        Sets distribution units. 
+
+        """
         return _libBornAgainCore.IDistribution1D_setUnits(self, units)
 
 IDistribution1D_swigregister = _libBornAgainCore.IDistribution1D_swigregister
@@ -8389,7 +8396,14 @@ class DistributionLogNormal(IDistribution1D):
 
 
     def setUnits(self, units):
-        """setUnits(DistributionLogNormal self, std::string const & units)"""
+        """
+        setUnits(DistributionLogNormal self, std::string const & units)
+
+        void DistributionLogNormal::setUnits(const std::string &units)
+
+        Sets distribution units. 
+
+        """
         return _libBornAgainCore.DistributionLogNormal_setUnits(self, units)
 
 DistributionLogNormal_swigregister = _libBornAgainCore.DistributionLogNormal_swigregister
@@ -17536,7 +17550,7 @@ class HomogeneousMaterial(INamed):
         __init__(HomogeneousMaterial self, std::string const & name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetization) -> HomogeneousMaterial
         __init__(HomogeneousMaterial self, std::string const & name, double refractive_index_delta, double refractive_index_beta) -> HomogeneousMaterial
 
-        HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetic_field=kvector_t())
+        HomogeneousMaterial::HomogeneousMaterial(const std::string &name, double refractive_index_delta, double refractive_index_beta, kvector_t magnetization=kvector_t())
 
         Constructs a material with  name and refractive_index parameters delta and beta (n = 1 - delta + i*beta). 
 
@@ -17555,7 +17569,7 @@ class HomogeneousMaterial(INamed):
 
         HomogeneousMaterial HomogeneousMaterial::inverted() const
 
         Constructs a material with inverted magnetic field. 
 
         """
         return _libBornAgainCore.HomogeneousMaterial_inverted(self)
@@ -17614,12 +17628,26 @@ class HomogeneousMaterial(INamed):
 
 
     def magnetization(self):
-        """magnetization(HomogeneousMaterial self) -> kvector_t"""
+        """
+        magnetization(HomogeneousMaterial self) -> kvector_t
+
+        kvector_t HomogeneousMaterial::magnetization() const
+
+        Get the magnetization (in A/m) 
+
+        """
         return _libBornAgainCore.HomogeneousMaterial_magnetization(self)
 
 
     def setMagnetization(self, magnetization):
-        """setMagnetization(HomogeneousMaterial self, kvector_t magnetization)"""
+        """
+        setMagnetization(HomogeneousMaterial self, kvector_t magnetization)
+
+        void HomogeneousMaterial::setMagnetization(const kvector_t magnetization)
+
+        Set the magnetizationd (in A/m) 
+
+        """
         return _libBornAgainCore.HomogeneousMaterial_setMagnetization(self, magnetization)
 
 
@@ -17555,7 +17569,7 @@ class HomogeneousMaterial(INamed):
         HomogeneousMaterial HomogeneousMaterial::inverted() const
 
-        Constructs a material with inverted magnetic field. 
+        Constructs a material with inverted magnetization. 
 
         """
-- 
GitLab